* ==============================================================================
* Date  : 28.01.2019 
* Paper : Exports and governance: the role of private voluntary agrifood standards	   
* Author: Dela-Dem Doe Fiankor, Inmaculada Martinez-Zarzoso, Bernhard Brümmer
* E-mail: dfianko@agr.uni-goettingen.de
*
* Stata: Version 15
*
* Notes: i = exporter (EXP)
*        j = importer (IMP)
*        k = product  (HSCode)
*        t = time	  (Year)
* ==============================================================================
	clear all
	set matsize 11000
	set maxvar 32767
	set more off, perm
	cd "/Users/ddfiankor/ownCloud/Projects/Exports & Governance/Data"

	use dataset_1, clear 
	egen id = group(EXP IMP HSCode) 
	xtset id Year	

* Generate Governance Distance measure
* ====================================
foreach a in VA_i RL_i RQ_i PS_i GE_i CC_i {
	sum	`a', detail
	scalar  Var_`a'	=	r(Var)
	gen 	Var_`a'	=	r(Var)
}
bys EXP IMP: gen VOICE  = (VA_i - VA_j)^2 / Var_VA
bys EXP IMP: gen STAB	= (PS_i - PS_j)^2 / Var_PS
bys EXP IMP: gen LAW	= (RL_i - RL_j)^2 / Var_RL
bys EXP IMP: gen CORR   = (CC_i - CC_j)^2 / Var_CC
bys EXP IMP: gen GOVT   = (GE_i - GE_j)^2 / Var_GE
bys EXP IMP: gen REG    = (RQ_i - RQ_j)^2 / Var_RQ

gen PGD = (VOICE + STAB + LAW + CORR + GOVT + REG) / 6 
	
* Generate GlobalGAP certification dummy
* ======================================
foreach a in Hect {
	gen d`a' = 0 
	replace d`a' = 1 if `a' > 0
	}
	
* Generate lags and logs
* ======================
foreach a in Hect Prod dHect PGD {
	bys id: gen `a'_g  = `a'[_n-1]
	}
	destring Distwces, force replace
foreach c of varlist y Dist* {
	gen ln`c' = ln(`c')
}
foreach c of varlist Hect Hect_g Prod_g Tariff {
	gen ln`c' = ln(1+`c')
}

* Generate the interaction term between Governance Distance and GlobalGAP
* =======================================================================
gen PGD_GAP  = PGD_g * dHect_g

gen EFTA = 1 if IMP=="AUT"|IMP=="BEL"|IMP=="BGR"|IMP=="CYP"|IMP=="CZE"|IMP=="DNK"|IMP=="EST"|IMP=="FIN"|IMP=="FRA"|IMP=="DEU"|IMP=="GRC"|IMP=="HUN"|IMP=="IRL"|IMP=="ITA"|IMP=="PRT"|IMP=="LVA" ///
		       |IMP=="LTU"|IMP=="LUX"|IMP=="MLT"|IMP=="NLD"|IMP=="POL"|IMP=="ROU"|IMP=="SVK"|IMP=="SVN"|IMP=="ESP"|IMP=="SWE"|IMP=="GBR"|IMP=="LIE"|IMP=="ISL"|IMP=="NOR"|IMP=="CHE"
	replace EFTA = 0 if EFTA==.
		
gen EFTA_i = 1 if EXP=="AUT"|EXP=="BEL"|EXP=="BGR"|EXP=="CYP"|EXP=="CZE"|EXP=="DNK"|EXP=="EST"|EXP=="FIN"|EXP=="FRA"|EXP=="DEU"|EXP=="GRC"|EXP=="HUN"|EXP=="IRL"|EXP=="ITA"|EXP=="PRT"|EXP=="LVA" ///
		         |EXP=="LTU"|EXP=="LUX"|EXP=="MLT"|EXP=="NLD"|EXP=="POL"|EXP=="ROU"|EXP=="SVK"|EXP=="SVN"|EXP=="ESP"|EXP=="SWE"|EXP=="GBR"|EXP=="LIE"|EXP=="ISL"|EXP=="NOR"|EXP=="CHE"
	replace EFTA_i = 0 if EFTA_i==.
		
* Regression analysis
* ===================

* Generate FEs to control for MRT
	egen ikt = group(EXP HSCode Year)
	egen jkt = group(IMP HSCode Year) 

* Table 3 (Benchmark specification)
* =================================
	global xij  		lnDistwces  Language  Colony Contig RTA lnTariff		
	global ifcondition 	if EXP!=IMP & EFTA==1 & EFTA_i==0

	eststo: reghdfe lny $xij PGD_g 			$ifcondition, absorb(jkt ikt)   cluster(id)
	eststo: reghdfe lny $xij PGD_g PGD_GAP 	$ifcondition, absorb(jkt ikt)   cluster(id)
	eststo: poi2hdfe y 	$xij PGD_g  		$ifcondition, id1(jkt) id2(ikt) cluster(id)
	eststo: poi2hdfe y 	$xij PGD_g PGD_GAP 	$ifcondition, id1(jkt) id2(ikt) cluster(id)
	
	** the code below will yield similar findings
	** eststo: ppml_panel_sg y  $xij if EXP!=IMP, exporter(EXP) importer(IMP) year(Year) nopair cluster(id)
	
	outreg2 [est*] using "Results/Table3.xls", dec(3) drop(o.* $FE YEAR_FE* $MRT)  replace
	erase "Results/Table3.txt"
	drop _est*
	
* Table 4: income level and product heterogeneities
* =================================================
* a. Income groups
	replace  Incomegroup="High Income" if Incomegroup =="High income: OECD"
	replace  Incomegroup="High Income" if Incomegroup =="High income: nonOECD"
	replace  Incomegroup="Low Income"  if Incomegroup =="Lower middle income"
	replace  Incomegroup="Low Income"  if Incomegroup =="Upper middle income"
	replace  Incomegroup="Low Income"  if Incomegroup =="Low income"
	
	tab Incomegroup, gen(INC) 
foreach c in dHect_g  {
	gen INC2`c' = `c'*INC2 // Developing countries
	gen INC1`c' = `c'*INC1
	}
	
	gen PGD_GAPdn  = PGD_g * INC2dHect_g
	gen PGD_GAPdd  = PGD_g * INC1dHect_g
	
	eststo: reghdfe lny $xij PGD_g PGD_GAPdn PGD_GAPdd 	$ifcondition, absorb(jkt ikt)   cluster(id)
	eststo: poi2hdfe y 	$xij PGD_g PGD_GAPdn PGD_GAPdd 	$ifcondition, id1(jkt) id2(ikt) cluster(id)
	
* b. Product specific analysis
	gen int dApple = 0
	gen int dBanan = 0
	gen int dGrape = 0

	replace dApple=1 if HSCode==808
	replace dBanan=1 if HSCode==803
	replace dGrape=1 if HSCode==806

	gen apple   = dApple * dHect_g
	gen banana  = dBanan * dHect_g
	gen grape   = dGrape * dHect_g
	
	gen PGDGAPapple   = apple  * PGD_g
	gen PGDGAPbanana  = banana * PGD_g
	gen PGDGAPgrape   = grape  * PGD_g
	
	eststo: reghdfe lny $xij PGD_g PGDGAPapple PGDGAPbanana PGDGAPgrape 	$ifcondition, absorb(jkt ikt)   cluster(id)
	eststo: poi2hdfe  y $xij PGD_g PGDGAPapple PGDGAPbanana PGDGAPgrape 	$ifcondition, id1(jkt) id2(ikt) cluster(id)

	outreg2 [est*] using "Results/Table4.xls", dec(3) drop(o.* $FE YEAR_FE* $MRT)  replace
	erase "Results/Table4.txt"
	drop _est*

	
* Table 5: Here we extend the analysis to bilateral trade flows between all countries
* ===================================================================================
	eststo: reghdfe lny $xij PGD_g 			if EXP!=IMP, absorb(jkt ikt)   cluster(id)
	eststo: reghdfe lny $xij PGD_g PGD_GAP 	if EXP!=IMP, absorb(jkt ikt)   cluster(id)
	eststo: poi2hdfe  y $xij PGD_g  		if EXP!=IMP, id1(jkt) id2(ikt) cluster(id)
	eststo: poi2hdfe  y $xij PGD_g PGD_GAP 	if EXP!=IMP, id1(jkt) id2(ikt) cluster(id)	
	outreg2 [est*] using "Results/Table5.xls", dec(3) replace
	erase "Results/Table5.txt"
	drop _est*
	
* Table 6: See further below

* ==============================================================================
* APPENDIX
* ==============================================================================

* Table A4: Individual components of the aggregate index
* ======================================================	
foreach a in VOICE STAB LAW CORR GOVT REG{
	bys id: gen `a'_  = `a'[_n-1]
	}
foreach a in VOICE_ STAB_ LAW_ CORR_ GOVT_ REG_{
	gen `a'GAP  = `a'* dHect_g
	}

	eststo: reghdfe lny $xij VOICE_ VOICE_GAP	$ifcondition, absorb(jkt ikt) 	cluster(id)
	eststo: poi2hdfe y 	$xij VOICE_ VOICE_GAP 	$ifcondition, id1(jkt) id2(ikt) cluster(id)
	eststo: reghdfe lny $xij STAB_  STAB_GAP 	$ifcondition, absorb(jkt ikt) 	cluster(id)
	eststo: poi2hdfe y 	$xij STAB_  STAB_GAP 	$ifcondition, id1(jkt) id2(ikt) cluster(id)
	eststo: reghdfe lny $xij LAW_   LAW_GAP 	$ifcondition, absorb(jkt ikt) 	cluster(id)
	eststo: poi2hdfe y 	$xij LAW_   LAW_GAP 	$ifcondition, id1(jkt) id2(ikt) cluster(id)
	eststo: reghdfe lny $xij CORR_  CORR_GAP 	$ifcondition, absorb(jkt ikt) 	cluster(id)
	eststo: poi2hdfe y 	$xij CORR_  CORR_GAP 	$ifcondition, id1(jkt) id2(ikt) cluster(id)
	eststo: reghdfe lny $xij GOVT_  GOVT_GAP 	$ifcondition, absorb(jkt ikt) 	cluster(id)
	eststo: poi2hdfe y 	$xij GOVT_  GOVT_GAP 	$ifcondition, id1(jkt) id2(ikt) cluster(id)
	eststo: reghdfe lny $xij REG_   REG_GAP 	$ifcondition, absorb(jkt ikt) 	cluster(id)
	eststo: poi2hdfe y 	$xij REG_   REG_GAP 	$ifcondition, id1(jkt) id2(ikt) cluster(id)
	
	outreg2 [est*] using "Results/Table4.xls", dec(3) drop(o.* $FE YEAR_FE* $MRT)  replace
	erase "Results/Table4.txt"
	drop _est*
	
* Table A5: Measure of certification: the number of certified farmers
* ===================================================================
	gen PGD_GAP2 = PGD_g * lnProd_g
	eststo: reghdfe lny $xij PGD_g PGD_GAP2  $ifcondition, absorb(jkt ikt)   cluster(id)
	eststo: poi2hdfe y 	$xij PGD_g PGD_GAP2  $ifcondition, id1(jkt) id2(ikt) cluster(id)
	
	outreg2 [est*] using "Results/Table6b.xls", dec(3) drop(o.* $FE YEAR_FE* $MRT)  replace
	erase "Results/Table6b.txt"
	drop _est*
	
* Table A6: Using diﬀerent measures of institutional quality
* ==========================================================

* A. Legatum dataset
* ==================
foreach a in lp_i ppr_i ipr_i {
	sum	`a', detail
	scalar  Var_`a'	=	r(Var)
	gen 	Var_`a'	=	r(Var)
}

bys EXP IMP: gen LP   = (lp_i  - lp_j)^2  / Var_lp
bys EXP IMP: gen PPR  = (ppr_i - ppr_j)^2 / Var_ppr
bys EXP IMP: gen IPR  = (ipr_i - ipr_j)^2 / Var_ipr

gen PGD_LGT = (LP + PPR + IPR ) / 3

* B. Freedom House dataset 
* ========================
foreach a in SG_i LS_i SM_i FT_i R_i {
	sum	`a', detail
	scalar  Var_`a'	=	r(Var)
	gen 	Var_`a'	=	r(Var)
}

bys EXP IMP: gen SG   = (SG_i  - SG_j)^2 / Var_SG
bys EXP IMP: gen LS   = (LS_i - LS_j)^2  / Var_LS
bys EXP IMP: gen SM   = (SM_i - SM_j)^2  / Var_SM
bys EXP IMP: gen FT   = (FT_i - FT_j)^2  / Var_FT
bys EXP IMP: gen R    = (R_i - R_j)^2    / Var_R_i

gen PGD_FH = (SG + LS + SM + FT + R ) / 5

foreach a in PGD_LGT PGD_FH {
	bys id: gen `a'_g  = `a'[_n-1]
	}
	
gen PGD_GAP_LGT  = PGD_LGT_g * dHect_g
gen PGD_GAP_FH   = PGD_FH_g  * dHect_g

	eststo: reghdfe lny $xij PGD_LGT_g 				$ifcondition, absorb(jkt ikt)   cluster(id)
	eststo: reghdfe lny $xij PGD_LGT_g	PGD_GAP_LGT $ifcondition, absorb(jkt ikt)   cluster(id)
	eststo: poi2hdfe y 	$xij PGD_LGT_g  			$ifcondition, id1(jkt) id2(ikt) cluster(id)
	eststo: poi2hdfe y 	$xij PGD_LGT_g	PGD_GAP_LGT $ifcondition, id1(jkt) id2(ikt) cluster(id)
	
	eststo: reghdfe lny $xij PGD_FH_g 				$ifcondition, absorb(jkt ikt)   cluster(id)
	eststo: reghdfe lny $xij PGD_FH_g	PGD_GAP_FH 	$ifcondition, absorb(jkt ikt)   cluster(id)
	eststo: poi2hdfe y 	$xij PGD_FH_g  				$ifcondition, id1(jkt) id2(ikt) cluster(id)
	eststo: poi2hdfe y 	$xij PGD_FH_g	PGD_GAP_FH 	$ifcondition, id1(jkt) id2(ikt) cluster(id)
	
	outreg2 [est*] using "Results/TableLGT.xls", dec(3) drop(o.* $FE YEAR_FE* $MRT)  replace
	erase "Results/Table3.txt"
	drop _est*
	

* Table 6: All fruits and vegetables
* ==================================
	use dataset_2, clear
	egen id = group(EXP IMP) 
	xtset id Year	

foreach a in VA_i RL_i RQ_i PS_i GE_i CC_i {
	sum	`a', detail
	scalar  Var_`a'	=	r(Var)
	gen 	Var_`a'	=	r(Var)
}
	gen VOICE   = (VA_i - VA_j)^2 / Var_VA
	gen STAB	= (PS_i - PS_j)^2 / Var_PS
	gen LAW		= (RL_i - RL_j)^2 / Var_RL
	gen CORR   	= (CC_i - CC_j)^2 / Var_CC
	gen GOVT   	= (GE_i - GE_j)^2 / Var_GE
	gen REG    	= (RQ_i - RQ_j)^2 / Var_RQ

gen PGD = (VOICE + STAB + LAW + CORR + GOVT + REG) / 6 
	
foreach a in GAP {
	gen d`a' = 0 
	replace d`a' = 1 if `a' > 0
	}
foreach a in dGAP GAP PGD {
	bys id: gen `a'_g  = `a'[_n-1]
	}
foreach c of varlist DIST y{
	gen ln`c' = ln(`c')
}
foreach c of varlist GAP GAP_g Tariff{
	gen ln`c' = ln(1+`c')
}
gen PGD_GAP = PGD_g * dGAP_g


gen EFTA = 1 if IMP=="AUT"|IMP=="BEL"|IMP=="BGR"|IMP=="CYP"|IMP=="CZE"|IMP=="DNK"|IMP=="EST"|IMP=="FIN"|IMP=="FRA"|IMP=="DEU"|IMP=="GRC"|IMP=="HUN"|IMP=="IRL"|IMP=="ITA"|IMP=="PRT"|IMP=="LVA" ///
			   |IMP=="LTU"|IMP=="LUX"|IMP=="MLT"|IMP=="NLD"|IMP=="POL"|IMP=="ROU"|IMP=="SVK"|IMP=="SVN"|IMP=="ESP"|IMP=="SWE"|IMP=="GBR"|IMP=="LIE"|IMP=="ISL"|IMP=="NOR"|IMP=="CHE"
replace EFTA = 0 if EFTA==.
	
gen EFTA_i = 1 if EXP=="AUT"|EXP=="BEL"|EXP=="BGR"|EXP=="CYP"|EXP=="CZE"|EXP=="DNK"|EXP=="EST"|EXP=="FIN"|EXP=="FRA"|EXP=="DEU"|EXP=="GRC"|EXP=="HUN"|EXP=="IRL"|EXP=="ITA"|EXP=="PRT"|EXP=="LVA" ///
		         |EXP=="LTU"|EXP=="LUX"|EXP=="MLT"|EXP=="NLD"|EXP=="POL"|EXP=="ROU"|EXP=="SVK"|EXP=="SVN"|EXP=="ESP"|EXP=="SWE"|EXP=="GBR"|EXP=="LIE"|EXP=="ISL"|EXP=="NOR"|EXP=="CHE"
replace EFTA_i = 0 if EFTA_i==.

	egen it = group(EXP Year)
	egen jt = group(IMP Year) 
	drop if Year<2010

	global xij 			lnDIST CLNG COL CONTIG  RTA lnTariff
	global ifcondition 	if EXP!=IMP & EFTA==1 & EFTA_i==0

	eststo: reghdfe  lny $xij PGD_g PGD_GAP $ifcondition, absorb(jt it)   cluster(id) 
	eststo: poi2hdfe y 	 $xij PGD_g PGD_GAP $ifcondition, id1(jt) id2(it) cluster(id)
	
	outreg2 [est*] using "Results/Table6.xls", dec(3) drop(o.* $FE YEAR_FE* $MRT)  replace
	erase "Results/Table6.txt"
	
clear
exit
